@@ -1,4 +1,4 @@
-# Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
@@ -61,16 +61,19 @@ DEFAULT_CONFIGURATION = {
     'ssl_cert': None,
     'ssl_key': None,
     'ssl_verify_cert': False,
+    'ssl_verify_identity': False,
     'ssl_cipher': None,
     'ssl_disabled': False,
+    'ssl_version': None,
     'passwd': None,
     'db': None,
     'connect_timeout': None,
     'dsn': None,
     'force_ipv6': False,
     'auth_plugin': None,
-    'allow_local_infile': True,
+    'allow_local_infile': False,
     'consume_results': False,
+    'conn_attrs': None,
 }
 
 CNX_POOL_ARGS = ('pool_name', 'pool_size', 'pool_reset_session')
@@ -446,7 +449,7 @@ class ClientFlag(_Flags):
         SECURE_CONNECTION,
         MULTI_STATEMENTS,
         MULTI_RESULTS,
-        LOCAL_FILES,
+        CONNECT_ARGS
     ]
 
     @classmethod
@@ -781,3 +784,7 @@ class SQLMode(_Constants):
                     and not hasattr(getattr(cls, key), '__call__'):
                 res.append(key)
         return tuple(sorted(res))
+
+CONN_ATTRS_DN = ["_pid", "_platform", "_source_host", "_client_name",
+                 "_client_license", "_client_version", "_os", "_connector_name",
+                 "_connector_license", "_connector_version"]
